@@ -1,9 +1,7 @@
 package App::perlfind::Plugin::Label;
-use 5.008;
 use strict;
 use warnings;
 use App::perlfind;
-our $VERSION = '2.05';
 App::perlfind->add_trigger(
     'matches.add' => sub {
         my ($class, $word, $matches) = @_;
