@@ -1,9 +1,7 @@
 package App::perlfind::Plugin::Perlvar;
-use 5.008;
 use strict;
 use warnings;
 use App::perlfind;
-our $VERSION = '2.05';
 
 # Generate %is_var with "util/perlvar-extract.pl". The value is what
 # the query key gets rewritten as.
@@ -244,8 +242,8 @@ my %is_var = (
             '%LAST_MATCH_START' => '%LAST_MATCH_START'
           );
 
-# find __WARN__, WARN, INT etc. as %SIG.
-$is_var{$_} = '%SIG' for qw(WARN DIE), keys %SIG;
+# find __WARN__, INT etc. as %SIG.
+$is_var{$_} = '%SIG' for qw(__WARN__ __DIE__ INT QUIT PIPE), keys %SIG;
 
 App::perlfind->add_trigger(
     'matches.add' => sub {
